@@ -5,9 +5,10 @@ libtmux.window
 
 """
 
+from __future__ import annotations
+
 import dataclasses
 import logging
-import pathlib
 import shlex
 import typing as t
 import warnings
@@ -16,19 +17,29 @@ from libtmux._internal.query_list import QueryList
 from libtmux.common import has_gte_version, tmux_cmd
 from libtmux.constants import (
     RESIZE_ADJUSTMENT_DIRECTION_FLAG_MAP,
+    PaneDirection,
     ResizeAdjustmentDirection,
+    WindowDirection,
 )
 from libtmux.neo import Obj, fetch_obj, fetch_objs
 from libtmux.pane import Pane
 
 from . import exc
-from .common import PaneDict, WindowOptionDict, handle_option_error, has_lt_version
-from .formats import FORMAT_SEPARATOR
+from .common import PaneDict, WindowOptionDict, handle_option_error
 
 if t.TYPE_CHECKING:
+    import sys
+    import types
+
     from .server import Server
     from .session import Session
 
+    if sys.version_info >= (3, 11):
+        from typing import Self
+    else:
+        from typing_extensions import Self
+
+
 logger = logging.getLogger(__name__)
 
 
@@ -71,6 +82,13 @@ class Window(Obj):
     >>> window in session.windows
     True
 
+    The window can be used as a context manager to ensure proper cleanup:
+
+    >>> with session.new_window() as window:
+    ...     pane = window.split()
+    ...     # Do work with the pane
+    ...     # Window will be killed automatically when exiting the context
+
     References
     ----------
     .. [window_manual] tmux window. openbsd manpage for TMUX(1).
@@ -81,7 +99,40 @@ class Window(Obj):
        https://man.openbsd.org/tmux.1#DESCRIPTION. Accessed April 1st, 2018.
     """
 
-    server: "Server"
+    server: Server
+
+    def __enter__(self) -> Self:
+        """Enter the context, returning self.
+
+        Returns
+        -------
+        :class:`Window`
+            The window instance
+        """
+        return self
+
+    def __exit__(
+        self,
+        exc_type: type[BaseException] | None,
+        exc_value: BaseException | None,
+        exc_tb: types.TracebackType | None,
+    ) -> None:
+        """Exit the context, killing the window if it exists.
+
+        Parameters
+        ----------
+        exc_type : type[BaseException] | None
+            The type of the exception that was raised
+        exc_value : BaseException | None
+            The instance of the exception that was raised
+        exc_tb : types.TracebackType | None
+            The traceback of the exception that was raised
+        """
+        if (
+            self.window_id is not None
+            and len(self.session.windows.filter(window_id=self.window_id)) > 0
+        ):
+            self.kill()
 
     def refresh(self) -> None:
         """Refresh window attributes from tmux."""
@@ -94,7 +145,7 @@ class Window(Obj):
         )
 
     @classmethod
-    def from_window_id(cls, server: "Server", window_id: str) -> "Window":
+    def from_window_id(cls, server: Server, window_id: str) -> Window:
         """Create Window from existing window_id."""
         window = fetch_obj(
             obj_key="window_id",
@@ -106,7 +157,7 @@ class Window(Obj):
         return cls(server=server, **window)
 
     @property
-    def session(self) -> "Session":
+    def session(self) -> Session:
         """Parent session of window."""
         assert isinstance(self.session_id, str)
         from libtmux.session import Session
@@ -114,14 +165,14 @@ class Window(Obj):
         return Session.from_session_id(server=self.server, session_id=self.session_id)
 
     @property
-    def panes(self) -> QueryList["Pane"]:
+    def panes(self) -> QueryList[Pane]:
         """Panes contained by window.
 
         Can be accessed via
         :meth:`.panes.get() <libtmux._internal.query_list.QueryList.get()>` and
         :meth:`.panes.filter() <libtmux._internal.query_list.QueryList.filter()>`
         """
-        panes: t.List["Pane"] = [
+        panes: list[Pane] = [
             Pane(server=self.server, **obj)
             for obj in fetch_objs(
                 list_cmd="list-panes",
@@ -141,11 +192,12 @@ class Window(Obj):
         self,
         cmd: str,
         *args: t.Any,
+        target: str | int | None = None,
     ) -> tmux_cmd:
         """Execute tmux subcommand within window context.
 
-        Automatically adds ``-t`` for object's indow ID to the command. Pass ``-t``
-        in args to override.
+        Automatically binds target by adding  ``-t`` for object's window ID to the
+        command. Pass ``target`` to keyword arguments to override.
 
         Examples
         --------
@@ -160,20 +212,25 @@ class Window(Obj):
         ... 'split-window', '-P', '-F#{pane_id}').stdout[0], server=session.server)
         Pane(%... Window(@... ...:..., Session($1 libtmux_...)))
 
+        Parameters
+        ----------
+        target : str, optional
+            Optional custom target override. By default, the target is the window ID.
+
         Returns
         -------
         :meth:`server.cmd`
         """
-        if not any("-t" in str(x) for x in args):
-            args = ("-t", self.window_id, *args)
+        if target is None:
+            target = self.window_id
 
-        return self.server.cmd(cmd, *args)
+        return self.server.cmd(cmd, *args, target=target)
 
     """
     Commands (tmux-like)
     """
 
-    def select_pane(self, target_pane: t.Union[str, int]) -> t.Optional["Pane"]:
+    def select_pane(self, target_pane: str | int) -> Pane | None:
         """Select pane and return selected :class:`Pane`.
 
         ``$ tmux select-pane``.
@@ -187,30 +244,30 @@ class Window(Obj):
         -------
         :class:`Pane`
         """
-        if target_pane in ["-l", "-U", "-D", "-L", "-R"]:
-            proc = self.cmd("select-pane", "-t%s" % self.window_id, target_pane)
+        if target_pane in {"-l", "-U", "-D", "-L", "-R"}:
+            proc = self.cmd("select-pane", target_pane)
         else:
-            proc = self.cmd("select-pane", "-t%s" % target_pane)
+            proc = self.cmd("select-pane", target=target_pane)
 
         if proc.stderr:
             raise exc.LibTmuxException(proc.stderr)
 
         return self.active_pane
 
-    def split_window(
+    def split(
         self,
-        target: t.Optional[t.Union[int, str]] = None,
-        start_directory: t.Optional[str] = None,
+        /,
+        target: int | str | None = None,
+        start_directory: str | None = None,
         attach: bool = False,
-        vertical: bool = True,
-        shell: t.Optional[str] = None,
-        size: t.Optional[t.Union[str, int]] = None,
-        percent: t.Optional[int] = None,  # deprecated
-        environment: t.Optional[t.Dict[str, str]] = None,
-    ) -> "Pane":
-        """Split window and return the created :class:`Pane`.
-
-        Used for splitting window and holding in a python object.
+        direction: PaneDirection | None = None,
+        full_window_split: bool | None = None,
+        zoom: bool | None = None,
+        shell: str | None = None,
+        size: str | int | None = None,
+        environment: dict[str, str] | None = None,
+    ) -> Pane:
+        """Split window on active pane and return the created :class:`Pane`.
 
         Parameters
         ----------
@@ -219,10 +276,12 @@ class Window(Obj):
             True.
         start_directory : str, optional
             specifies the working directory in which the new window is created.
-        target : str
-            ``target_pane`` to split.
-        vertical : str
-            split vertically
+        direction : PaneDirection, optional
+            split in direction. If none is specified, assume down.
+        full_window_split: bool, optional
+            split across full window width or height, rather than active pane.
+        zoom: bool, optional
+            expand pane
         shell : str, optional
             execute a command on splitting the window.  The pane will close
             when the command exits.
@@ -232,121 +291,35 @@ class Window(Obj):
             window upon completion is desired.
         size: int, optional
             Cell/row or percentage to occupy with respect to current window.
-        percent: int, optional
-            Deprecated in favor of size. Percentage to occupy with respect to current
-            window.
         environment: dict, optional
             Environmental variables for new pane. tmux 3.0+ only. Passthrough to ``-e``.
-
-        Notes
-        -----
-        :term:`tmux(1)` will move window to the new pane if the
-        ``split-window`` target is off screen. tmux handles the ``-d`` the
-        same way as ``new-window`` and ``attach`` in
-        :class:`Session.new_window`.
-
-        By default, this will make the window the pane is created in
-        active. To remain on the same window and split the pane in another
-        target window, pass in ``attach=False``.
-
-        .. versionchanged:: 0.28.0
-
-           ``attach`` default changed from ``True`` to ``False``.
-
-        .. deprecated:: 0.28.0
-
-           ``percent=25`` deprecated in favor of ``size="25%"``.
         """
-        tmux_formats = ["#{pane_id}" + FORMAT_SEPARATOR]
-
-        tmux_args: t.Tuple[str, ...] = ()
-
-        if target is not None:
-            tmux_args += ("-t%s" % target,)
-        else:
-            if len(self.panes):
-                tmux_args += (
-                    f"-t{self.session_id}:{self.window_id}.{self.panes[0].pane_index}",
-                )
-            else:
-                tmux_args += (f"-t{self.session_id}:{self.window_id}",)
-
-        if vertical:
-            tmux_args += ("-v",)
-        else:
-            tmux_args += ("-h",)
-
-        if size is not None:
-            if has_lt_version("3.1"):
-                if isinstance(size, str) and size.endswith("%"):
-                    tmux_args += (f'-p{str(size).rstrip("%")}',)
-                else:
-                    warnings.warn(
-                        'Ignored size. Use percent in tmux < 3.1, e.g. "size=50%"',
-                        stacklevel=2,
-                    )
-            else:
-                tmux_args += (f"-l{size}",)
-
-        if percent is not None:
-            # Deprecated in 3.1 in favor of -l
-            warnings.warn(
-                f'Deprecated in favor of size="{str(percent).rstrip("%")}%" '
-                + ' ("-l" flag) in tmux 3.1+.',
-                category=DeprecationWarning,
-                stacklevel=2,
-            )
-            tmux_args += (f"-p{percent}",)
-
-        tmux_args += ("-P", "-F%s" % "".join(tmux_formats))  # output
-
-        if start_directory is not None:
-            # as of 2014-02-08 tmux 1.9-dev doesn't expand ~ in new-window -c.
-            start_path = pathlib.Path(start_directory).expanduser()
-            tmux_args += (f"-c{start_path}",)
-
-        if not attach:
-            tmux_args += ("-d",)
-
-        if environment:
-            if has_gte_version("3.0"):
-                for k, v in environment.items():
-                    tmux_args += (f"-e{k}={v}",)
-            else:
-                logger.warning(
-                    "Environment flag ignored, tmux 3.0 or newer required.",
-                )
-
-        if shell:
-            tmux_args += (shell,)
-
-        pane_cmd = self.cmd("split-window", *tmux_args)
-
-        # tmux < 1.7. This is added in 1.7.
-        if pane_cmd.stderr:
-            if "pane too small" in pane_cmd.stderr:
-                raise exc.LibTmuxException(pane_cmd.stderr)
-
-            raise exc.LibTmuxException(pane_cmd.stderr, self.__dict__, self.panes)
-
-        pane_output = pane_cmd.stdout[0]
-
-        pane_formatters = dict(zip(["pane_id"], pane_output.split(FORMAT_SEPARATOR)))
-
-        return Pane.from_pane_id(server=self.server, pane_id=pane_formatters["pane_id"])
+        active_pane = self.active_pane or self.panes[0]
+        return active_pane.split(
+            target=target,
+            start_directory=start_directory,
+            attach=attach,
+            direction=direction,
+            full_window_split=full_window_split,
+            zoom=zoom,
+            shell=shell,
+            size=size,
+            environment=environment,
+        )
 
     def resize(
         self,
+        /,
         # Adjustments
-        adjustment_direction: t.Optional[ResizeAdjustmentDirection] = None,
-        adjustment: t.Optional[int] = None,
+        adjustment_direction: ResizeAdjustmentDirection | None = None,
+        adjustment: int | None = None,
         # Manual
-        height: t.Optional[int] = None,
-        width: t.Optional[int] = None,
+        height: int | None = None,
+        width: int | None = None,
         # Expand / Shrink
-        expand: t.Optional[bool] = None,
-        shrink: t.Optional[bool] = None,
-    ) -> "Window":
+        expand: bool | None = None,
+        shrink: bool | None = None,
+    ) -> Window:
         """Resize tmux window.
 
         Parameters
@@ -386,18 +359,18 @@ class Window(Obj):
             warnings.warn("resize() requires tmux 2.9 or newer", stacklevel=2)
             return self
 
-        tmux_args: t.Tuple[str, ...] = ()
+        tmux_args: tuple[str, ...] = ()
 
-        ## Adjustments
+        # Adjustments
         if adjustment_direction:
             if adjustment is None:
-                raise exc.WindowAdjustmentDirectionRequiresAdjustment()
+                raise exc.WindowAdjustmentDirectionRequiresAdjustment
             tmux_args += (
                 f"{RESIZE_ADJUSTMENT_DIRECTION_FLAG_MAP[adjustment_direction]}",
                 str(adjustment),
             )
         elif height or width:
-            ## Manual resizing
+            # Manual resizing
             if height:
                 tmux_args += (f"-y{int(height)}",)
             if width:
@@ -416,11 +389,11 @@ class Window(Obj):
         self.refresh()
         return self
 
-    def last_pane(self) -> t.Optional["Pane"]:
+    def last_pane(self) -> Pane | None:
         """Return last pane."""
         return self.select_pane("-l")
 
-    def select_layout(self, layout: t.Optional[str] = None) -> "Window":
+    def select_layout(self, layout: str | None = None) -> Window:
         """Select layout for window.
 
         Wrapper for ``$ tmux select-layout <layout>``.
@@ -451,7 +424,7 @@ class Window(Obj):
             'custom'
                 custom dimensions (see :term:`tmux(1)` manpages).
         """
-        cmd = ["select-layout", f"-t{self.session_id}:{self.window_index}"]
+        cmd = ["select-layout"]
 
         if layout:  # tmux allows select-layout without args
             cmd.append(layout)
@@ -463,7 +436,7 @@ class Window(Obj):
 
         return self
 
-    def set_window_option(self, option: str, value: t.Union[int, str]) -> "Window":
+    def set_window_option(self, option: str, value: int | str) -> Window:
         """Set option for tmux window.
 
         Wraps ``$ tmux set-window-option <option> <value>``.
@@ -488,7 +461,6 @@ class Window(Obj):
 
         cmd = self.cmd(
             "set-window-option",
-            f"-t{self.session_id}:{self.window_index}",
             option,
             value,
         )
@@ -498,7 +470,7 @@ class Window(Obj):
 
         return self
 
-    def show_window_options(self, g: t.Optional[bool] = False) -> "WindowOptionDict":
+    def show_window_options(self, g: bool | None = False) -> WindowOptionDict:
         """Return dict of options for window.
 
         .. versionchanged:: 0.13.0
@@ -510,7 +482,7 @@ class Window(Obj):
         g : str, optional
             Pass ``-g`` flag for global variable, default False.
         """
-        tmux_args: t.Tuple[str, ...] = ()
+        tmux_args: tuple[str, ...] = ()
 
         if g:
             tmux_args += ("-g",)
@@ -524,7 +496,7 @@ class Window(Obj):
         # retaining quoted sub-strings.
         #   shlex.split('this is "a test"') => ['this', 'is', 'a test']
 
-        window_options: "WindowOptionDict" = {}
+        window_options: WindowOptionDict = {}
         for item in output:
             try:
                 key, val = shlex.split(item)
@@ -542,7 +514,7 @@ class Window(Obj):
         self,
         option: str,
         g: bool = False,
-    ) -> t.Optional[t.Union[str, int]]:
+    ) -> str | int | None:
         """Return option value for the target window.
 
         todo: test and return True/False for on/off string
@@ -558,7 +530,7 @@ class Window(Obj):
         :exc:`exc.OptionError`, :exc:`exc.UnknownOption`,
         :exc:`exc.InvalidOption`, :exc:`exc.AmbiguousOption`
         """
-        tmux_args: t.Tuple[t.Union[str, int], ...] = ()
+        tmux_args: tuple[str | int, ...] = ()
 
         if g:
             tmux_args += ("-g",)
@@ -577,13 +549,11 @@ class Window(Obj):
 
         value_raw = next(shlex.split(item) for item in window_options_output)
 
-        value: t.Union[str, int] = (
-            int(value_raw[1]) if value_raw[1].isdigit() else value_raw[1]
-        )
+        value: str | int = int(value_raw[1]) if value_raw[1].isdigit() else value_raw[1]
 
         return value
 
-    def rename_window(self, new_name: str) -> "Window":
+    def rename_window(self, new_name: str) -> Window:
         """Rename window.
 
         Parameters
@@ -619,7 +589,7 @@ class Window(Obj):
 
     def kill(
         self,
-        all_except: t.Optional[bool] = None,
+        all_except: bool | None = None,
     ) -> None:
         """Kill :class:`Window`.
 
@@ -657,7 +627,7 @@ class Window(Obj):
         >>> one_window_to_rule_them_all in session.windows
         True
         """
-        flags: t.Tuple[str, ...] = ()
+        flags: tuple[str, ...] = ()
 
         if all_except:
             flags += ("-a",)
@@ -670,13 +640,11 @@ class Window(Obj):
         if proc.stderr:
             raise exc.LibTmuxException(proc.stderr)
 
-        return None
-
     def move_window(
         self,
         destination: str = "",
-        session: t.Optional[str] = None,
-    ) -> "Window":
+        session: str | None = None,
+    ) -> Window:
         """Move current :class:`Window` object ``$ tmux move-window``.
 
         Parameters
@@ -692,7 +660,7 @@ class Window(Obj):
         proc = self.cmd(
             "move-window",
             f"-s{self.session_id}:{self.window_index}",
-            f"-t{session}:{destination}",
+            target=f"{session}:{destination}",
         )
 
         if proc.stderr:
@@ -705,10 +673,70 @@ class Window(Obj):
 
         return self
 
+    def new_window(
+        self,
+        window_name: str | None = None,
+        *,
+        start_directory: None = None,
+        attach: bool = False,
+        window_index: str = "",
+        window_shell: str | None = None,
+        environment: dict[str, str] | None = None,
+        direction: WindowDirection | None = None,
+    ) -> Window:
+        """Create new window respective of current window's position.
+
+        See Also
+        --------
+        :meth:`Session.new_window()`
+
+        Examples
+        --------
+        .. ::
+            >>> import pytest
+            >>> from libtmux.common import has_lt_version
+            >>> if has_lt_version('3.2'):
+            ...     pytest.skip('This doctest requires tmux 3.2 or newer')
+        >>> window_initial = session.new_window(window_name='Example')
+        >>> window_initial
+        Window(@... 2:Example, Session($1 libtmux_...))
+        >>> window_initial.window_index
+        '2'
+
+        >>> window_before = window_initial.new_window(
+        ... window_name='Window before', direction=WindowDirection.Before)
+        >>> window_initial.refresh()
+        >>> window_before
+        Window(@... 2:Window before, Session($1 libtmux_...))
+        >>> window_initial
+        Window(@... 3:Example, Session($1 libtmux_...))
+
+        >>> window_after = window_initial.new_window(
+        ... window_name='Window after', direction=WindowDirection.After)
+        >>> window_initial.refresh()
+        >>> window_after.refresh()
+        >>> window_after
+        Window(@... 4:Window after, Session($1 libtmux_...))
+        >>> window_initial
+        Window(@... 3:Example, Session($1 libtmux_...))
+        >>> window_before
+        Window(@... 2:Window before, Session($1 libtmux_...))
+        """
+        return self.session.new_window(
+            window_name=window_name,
+            start_directory=start_directory,
+            attach=attach,
+            window_index=window_index,
+            window_shell=window_shell,
+            environment=environment,
+            direction=direction,
+            target_window=self.window_id,
+        )
+
     #
     # Climbers
     #
-    def select(self) -> "Window":
+    def select(self) -> Window:
         """Select window.
 
         To select a window object asynchrously. If a ``window`` object exists
@@ -744,7 +772,7 @@ class Window(Obj):
     # Computed properties
     #
     @property
-    def active_pane(self) -> t.Optional["Pane"]:
+    def active_pane(self) -> Pane | None:
         """Return attached :class:`Pane`."""
         panes = self.panes.filter(pane_active="1")
         if len(panes) > 0:
@@ -762,19 +790,16 @@ class Window(Obj):
 
     def __repr__(self) -> str:
         """Representation of :class:`Window` object."""
-        return "{}({} {}:{}, {})".format(
-            self.__class__.__name__,
-            self.window_id,
-            self.window_index,
-            self.window_name,
-            self.session,
+        return (
+            f"{self.__class__.__name__}({self.window_id} "
+            + f"{self.window_index}:{self.window_name}, {self.session})"
         )
 
     #
     # Aliases
     #
     @property
-    def id(self) -> t.Optional[str]:
+    def id(self) -> str | None:
         """Alias of :attr:`Window.window_id`.
 
         >>> window.id
@@ -786,7 +811,7 @@ class Window(Obj):
         return self.window_id
 
     @property
-    def name(self) -> t.Optional[str]:
+    def name(self) -> str | None:
         """Alias of :attr:`Window.window_name`.
 
         >>> window.name
@@ -798,7 +823,7 @@ class Window(Obj):
         return self.window_name
 
     @property
-    def index(self) -> t.Optional[str]:
+    def index(self) -> str | None:
         """Alias of :attr:`Window.window_index`.
 
         >>> window.index
@@ -810,7 +835,7 @@ class Window(Obj):
         return self.window_index
 
     @property
-    def height(self) -> t.Optional[str]:
+    def height(self) -> str | None:
         """Alias of :attr:`Window.window_height`.
 
         >>> window.height.isdigit()
@@ -822,7 +847,7 @@ class Window(Obj):
         return self.window_height
 
     @property
-    def width(self) -> t.Optional[str]:
+    def width(self) -> str | None:
         """Alias of :attr:`Window.window_width`.
 
         >>> window.width.isdigit()
@@ -836,8 +861,62 @@ class Window(Obj):
     #
     # Legacy: Redundant stuff we want to remove
     #
+    def split_window(
+        self,
+        target: int | str | None = None,
+        start_directory: str | None = None,
+        attach: bool = False,
+        vertical: bool = True,
+        shell: str | None = None,
+        size: str | int | None = None,
+        percent: int | None = None,  # deprecated
+        environment: dict[str, str] | None = None,
+    ) -> Pane:
+        """Split window and return the created :class:`Pane`.
+
+        Notes
+        -----
+        .. deprecated:: 0.33.0
+
+           Deprecated in favor of :meth:`.split()`.
+
+        .. versionchanged:: 0.28.0
+
+           ``attach`` default changed from ``True`` to ``False``.
+
+        .. deprecated:: 0.28.0
+
+           ``percent=25`` deprecated in favor of ``size="25%"``.
+        """
+        warnings.warn(
+            "Window.split_window() is deprecated in favor of Window.split()",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
+
+        if percent is not None:
+            # Deprecated in 3.1 in favor of -l
+            warnings.warn(
+                f'Deprecated in favor of size="{str(percent).rstrip("%")}%" '
+                + ' ("-l" flag) in tmux 3.1+.',
+                category=DeprecationWarning,
+                stacklevel=2,
+            )
+            if size is None:
+                size = f"{str(percent).rstrip('%')}%"
+
+        return self.split(
+            target=target,
+            start_directory=start_directory,
+            attach=attach,
+            direction=PaneDirection.Below if vertical else PaneDirection.Right,
+            shell=shell,
+            size=size,
+            environment=environment,
+        )
+
     @property
-    def attached_pane(self) -> t.Optional["Pane"]:
+    def attached_pane(self) -> Pane | None:
         """Return attached :class:`Pane`.
 
         Notes
@@ -856,7 +935,7 @@ class Window(Obj):
             return panes[0]
         return None
 
-    def select_window(self) -> "Window":
+    def select_window(self) -> Window:
         """Select window.
 
         Notes
@@ -887,15 +966,12 @@ class Window(Obj):
             category=DeprecationWarning,
             stacklevel=2,
         )
-        proc = self.cmd(
-            "kill-window",
-            f"-t{self.session_id}:{self.window_index}",
-        )
+        proc = self.cmd("kill-window")
 
         if proc.stderr:
             raise exc.LibTmuxException(proc.stderr)
 
-    def get(self, key: str, default: t.Optional[t.Any] = None) -> t.Any:
+    def get(self, key: str, default: t.Any | None = None) -> t.Any:
         """Return key-based lookup. Deprecated by attributes.
 
         .. deprecated:: 0.16
@@ -905,7 +981,9 @@ class Window(Obj):
 
         """
         warnings.warn(
-            "Window.get() is deprecated", category=DeprecationWarning, stacklevel=2
+            "Window.get() is deprecated",
+            category=DeprecationWarning,
+            stacklevel=2,
         )
         return getattr(self, key, default)
 
@@ -925,7 +1003,7 @@ class Window(Obj):
         )
         return getattr(self, key)
 
-    def get_by_id(self, pane_id: str) -> t.Optional[Pane]:
+    def get_by_id(self, pane_id: str) -> Pane | None:
         """Return pane by id. Deprecated in favor of :meth:`.panes.get()`.
 
         .. deprecated:: 0.16
@@ -940,7 +1018,7 @@ class Window(Obj):
         )
         return self.panes.get(pane_id=pane_id, default=None)
 
-    def where(self, kwargs: t.Dict[str, t.Any]) -> t.List[Pane]:
+    def where(self, kwargs: dict[str, t.Any]) -> list[Pane]:
         """Filter through panes, return list of :class:`Pane`.
 
         .. deprecated:: 0.16
@@ -949,14 +1027,16 @@ class Window(Obj):
 
         """
         warnings.warn(
-            "Window.where() is deprecated", category=DeprecationWarning, stacklevel=2
+            "Window.where() is deprecated",
+            category=DeprecationWarning,
+            stacklevel=2,
         )
         try:
             return self.panes.filter(**kwargs)
         except IndexError:
             return []
 
-    def find_where(self, kwargs: t.Dict[str, t.Any]) -> t.Optional[Pane]:
+    def find_where(self, kwargs: dict[str, t.Any]) -> Pane | None:
         """Filter through panes, return first :class:`Pane`.
 
         .. deprecated:: 0.16
@@ -971,7 +1051,7 @@ class Window(Obj):
         )
         return self.panes.get(default=None, **kwargs)
 
-    def _list_panes(self) -> t.List[PaneDict]:
+    def _list_panes(self) -> list[PaneDict]:
         """Return list of panes (deprecated in favor of :meth:`.panes`).
 
         .. deprecated:: 0.16
@@ -987,7 +1067,7 @@ class Window(Obj):
         return [pane.__dict__ for pane in self.panes]
 
     @property
-    def _panes(self) -> t.List[PaneDict]:
+    def _panes(self) -> list[PaneDict]:
         """Property / alias to return :meth:`~._list_panes`.
 
         .. deprecated:: 0.16
@@ -998,7 +1078,7 @@ class Window(Obj):
         warnings.warn("_panes is deprecated", category=DeprecationWarning, stacklevel=2)
         return self._list_panes()
 
-    def list_panes(self) -> t.List["Pane"]:
+    def list_panes(self) -> list[Pane]:
         """Return list of :class:`Pane` for the window.
 
         .. deprecated:: 0.16
@@ -1007,12 +1087,14 @@ class Window(Obj):
 
         """
         warnings.warn(
-            "list_panes() is deprecated", category=DeprecationWarning, stacklevel=2
+            "list_panes() is deprecated",
+            category=DeprecationWarning,
+            stacklevel=2,
         )
         return self.panes
 
     @property
-    def children(self) -> QueryList["Pane"]:
+    def children(self) -> QueryList[Pane]:
         """Was used by TmuxRelationalObject (but that's longer used in this class).
 
         .. deprecated:: 0.16
@@ -1021,6 +1103,8 @@ class Window(Obj):
 
         """
         warnings.warn(
-            "Server.children is deprecated", category=DeprecationWarning, stacklevel=2
+            "Window.children is deprecated",
+            category=DeprecationWarning,
+            stacklevel=2,
         )
         return self.panes
